import { post, put, deleteRequest, get } from './api';
import axiosInstance from './axios'; // 用于处理特殊响应类型

/**
 * 文件管理接口模块
 * 包含文件上传、下载、更新、删除等操作
 */

// 文件上传接口
export function uploadFile(file) {
    const formData = new FormData();
    formData.append('file', file);
    return post('/file/files', formData);
}

// 文件下载接口（需要处理二进制流）
export function downloadFile(fileId) {
    return get(`/file/files/${fileId}`, {
        // responseType: 'blob', // 指定响应类型为二进制流
        // timeout: 15000 // 下载超时时间延长至15秒
    });
}

// 文件元数据更新接口
export function updateFileMetadata(fileId, newFilename) {
    return put(`/file/files/${fileId}`, {
        filename: newFilename
    });
}

// 文件删除接口
export function deleteFile(fileId) {
    return deleteRequest(`/file/files/${fileId}`);
}

// 批量文件操作接口
export function batchFileOperations(operations) {
    return post('/file/files/batch', { operations });
}

// 获取文件列表接口
export function getFiles(data) {
    return get('/file/files', data);
}
