import axios from 'axios';
import store from '@/store';
import router from '@/router';

// 创建axios实例
const service = axios.create({
    baseURL: '/api', // api的base_url，可以在.env文件中配置
    timeout: 5000, // 请求超时时间
});

// 请求拦截器
service.interceptors.request.use(
    (config) => {
        const token = localStorage.getItem('token');
        if (token) {
            config.headers['Authorization'] = 'Bearer ' + token;
        }
        return config;
    },
    (error) => {
        // 处理请求错误
        console.error(error); // for debug
        return Promise.reject(error);
    }
);

// 响应拦截器
service.interceptors.response.use(
    (response) => response.data,
    (error) => {
        if (error.response && error.response.status === 401) {
            store.commit('user/CLEAR_SESSION');
            router.push('/login?expired=1');
        }
        console.error('Error:', error); // 更清晰的错误日志输出
        return Promise.reject(error);
    }
);

export default service;
