import service from '@/apis/axios';
import axios from 'axios';
import {auth_logout} from "@/apis/apis_auth.js";
// 清除会话的辅助函数
const clearSession = (state, commit) => {
    state.info = null;
    state.lastLogin = null;
    localStorage.removeItem('userInfo');
    if (state.refreshTimer) {
        clearTimeout(state.refreshTimer);
        state.refreshTimer = null;
    }
    commit('CLEAR_SESSION');
};

export default {
    namespaced: true,
    state: () => ({
        info: null,
        lastLogin: null,
        refreshTimer: null,
    }),
    mutations: {
        SET_USER_INFO(state, payload) {
            state.info = {
                ...payload,
                isAdmin: payload.role === 'admin',
            };
            state.lastLogin = new Date().toISOString();
        },
        CLEAR_SESSION(state) {
            // state.info = null;
            // state.lastLogin = null;
            // localStorage.removeItem('userInfo');
            // if (state.refreshTimer) {
            //     clearTimeout(state.refreshTimer);
            //     state.refreshTimer = null;
            // }
            clearSession(state, () => {});
        },
    },
    actions: {
        async initialize({ commit }) {
            try {
                const rawData = localStorage.getItem('userInfo');
                if (rawData) {
                    const data = JSON.parse(rawData);
                    commit('SET_USER_INFO', {
                        ...data,
                        token: data.token ? atob(data.token) : null,
                    });
                }
            } catch (err) {
                console.error('初始化用户状态失败:', err);
                commit('CLEAR_SESSION'); // 直接调用 mutation 而不是 dispatch
            }
        },
        CLEAR_SESSION({ commit }) {
            // commit('CLEAR_SESSION');
            // localStorage.removeItem('userInfo');
            clearSession(this.state, commit);
        },
        async logout({commit}) {
            //向后端发起退出登录的请求
            try {
                await auth_logout(); // 调用退出登录API
            } catch (err) {
                console.error('退出登录失败:', err);
            }

            localStorage.removeItem('userInfo');
            delete service.defaults.headers.common['Authorization'];
            commit('CLEAR_SESSION');

            // 取消所有 pending 请求（可选）
            const CancelToken = axios.CancelToken;
            const source = CancelToken.source();
            source.cancel('用户主动退出登录');
        },
    },
};
